==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionDelayExponentialDelayBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionDelayExponentialDelayBuilder extends HTTPFaultInjectionDelayExponentialDelayFluentImpl<HTTPFaultInjectionDelayExponentialDelayBuilder> implements VisitableBuilder<HTTPFaultInjectionDelayExponentialDelay,HTTPFaultInjectionDelayExponentialDelayBuilder>{
  public HTTPFaultInjectionDelayExponentialDelayBuilder() {
    this(false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionDelayExponentialDelay(), validationEnabled);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionDelayExponentialDelay(), validationEnabled);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,HTTPFaultInjectionDelayExponentialDelay instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,HTTPFaultInjectionDelayExponentialDelay instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withExponentialDelay(instance.getExponentialDelay());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelay instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelay instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withExponentialDelay(instance.getExponentialDelay());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionDelayExponentialDelay build() {
    HTTPFaultInjectionDelayExponentialDelay buildable = new HTTPFaultInjectionDelayExponentialDelay(fluent.getExponentialDelay());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionDelayExponentialDelayBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionDelayExponentialDelayBuilder extends HTTPFaultInjectionDelayExponentialDelayFluent<HTTPFaultInjectionDelayExponentialDelayBuilder> implements VisitableBuilder<HTTPFaultInjectionDelayExponentialDelay,HTTPFaultInjectionDelayExponentialDelayBuilder>{
  public HTTPFaultInjectionDelayExponentialDelayBuilder() {
    this(false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionDelayExponentialDelay(), validationEnabled);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionDelayExponentialDelay(), validationEnabled);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,HTTPFaultInjectionDelayExponentialDelay instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent,HTTPFaultInjectionDelayExponentialDelay instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayExponentialDelay());

    if (instance != null) {
      fluent.withExponentialDelay(instance.getExponentialDelay());
      fluent.withExponentialDelay(instance.getExponentialDelay());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelay instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionDelayExponentialDelayBuilder(HTTPFaultInjectionDelayExponentialDelay instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayExponentialDelay());

    if (instance != null) {
      this.withExponentialDelay(instance.getExponentialDelay());
      this.withExponentialDelay(instance.getExponentialDelay());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionDelayExponentialDelayFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionDelayExponentialDelay build() {
    HTTPFaultInjectionDelayExponentialDelay buildable = new HTTPFaultInjectionDelayExponentialDelay(fluent.getExponentialDelay());
    return buildable;
  }
  
}
